@@ -35,6 +35,11 @@ import pytz
 import random
 import string
 import webbrowser
+def my_ip():
+    try:
+        return requests.get("https://api.ipify.org").text
+    except:
+        return "network error"
 def today(format="%Y-%m-%d"):
     return datetime.datetime.now().strftime(format)
 def rename(old, new):
